@@ -1,6 +1,6 @@
 // info.cpp
 
-// Copyright (C) 2012-2016 by Werner Lemberg.
+// Copyright (C) 2012-2017 by Werner Lemberg.
 //
 // This file is part of the ttfautohint library, and may only be used,
 // modified, and distributed under the terms given in `COPYING'.  By
@@ -67,14 +67,14 @@ check_family_suffix(const char* s)
 int
 build_version_string(Info_Data* idata)
 {
-  // since we use `goto' we have to initialize variables before the jumps
+  // since we use `goto' we have to declare variables before the jumps
   unsigned char* info_string;
   unsigned char* info_string_wide;
   unsigned char* dt;
   unsigned char* dtw;
   char* s = NULL;
-  char strong[4];
-  int count;
+  char mode[4];
+  char mode_letters[] = "nqs";
   int ret = 0;
   sds d;
 
@@ -103,22 +103,20 @@ build_version_string(Info_Data* idata)
     d = sdscatprintf(d, " -m \"%s\"", bn ? bn : idata->control_name);
     free(bn);
   }
+  if (idata->reference_name)
+  {
+    char* bn = base_name(idata->reference_name);
+    d = sdscatprintf(d, " -R \"%s\"", bn ? bn : idata->reference_name);
+    free(bn);
 
-  count = 0;
-  strong[0] = '\0';
-  strong[1] = '\0';
-  strong[2] = '\0';
-  strong[3] = '\0';
-  if (idata->gray_strong_stem_width)
-    strong[count++] = 'g';
-  if (idata->gdi_cleartype_strong_stem_width)
-    strong[count++] = 'G';
-  if (idata->dw_cleartype_strong_stem_width)
-    strong[count++] = 'D';
-  if (*strong)
-    d = sdscatprintf(d, " -w %s", strong);
-  else
-    d = sdscat(d, " -w \"\"");
+    d = sdscatprintf(d, " -Z %d", idata->reference_index);
+  }
+  // `*_stem_width_mode' can have values -1, 0, and 1
+  mode[0] = mode_letters[idata->gray_stem_width_mode + 1];
+  mode[1] = mode_letters[idata->gdi_cleartype_stem_width_mode + 1];
+  mode[2] = mode_letters[idata->dw_cleartype_stem_width_mode + 1];
+  mode[3] = '\0';
+  d = sdscatprintf(d, " -a %s", mode);
 
   if (idata->windows_compatibility)
     d = sdscat(d, " -W");
@@ -128,6 +126,8 @@ build_version_string(Info_Data* idata)
     d = sdscat(d, " -c");
   if (idata->symbol)
     d = sdscat(d, " -s");
+  if (idata->fallback_scaling)
+    d = sdscat(d, " -S");
   if (idata->TTFA_info)
     d = sdscat(d, " -t");
 
@@ -633,7 +633,7 @@ info_post(void* user)
       *(fps++) = c;
   }
   // set correct size
-  sdsIncrLen(family_ps_suffix, fps - family_ps_suffix);
+  sdsIncrLen(family_ps_suffix, (int)(fps - family_ps_suffix));
 
   size_t family_ps_suffix_len = sdslen(family_ps_suffix);
 
@@ -789,7 +789,7 @@ info_post(void* user)
       }
     }
     // set correct size
-    sdsIncrLen(family_ps_name, fpn - family_ps_name);
+    sdsIncrLen(family_ps_name, (int)(fpn - family_ps_name));
 
     sds ps_suffix = is_wide ? family_ps_suffix_wide : family_ps_suffix;
     insert_suffix(ps_suffix,
